summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorDinnerbone <dinnerbone@dinnerbone.com>2011-10-03 00:34:04 +0100
committerDinnerbone <dinnerbone@dinnerbone.com>2011-10-03 00:34:04 +0100
commit050bd70a5dfd09f0447c7a9d0412d9a714cae1cd (patch)
tree49f8bb4e9fcc88b8d87550b2362460c199b82cde /src
parent489d3e3138600ad208685d61fd2abb1885806952 (diff)
downloadbukkit-050bd70a5dfd09f0447c7a9d0412d9a714cae1cd.tar
bukkit-050bd70a5dfd09f0447c7a9d0412d9a714cae1cd.tar.gz
bukkit-050bd70a5dfd09f0447c7a9d0412d9a714cae1cd.tar.lz
bukkit-050bd70a5dfd09f0447c7a9d0412d9a714cae1cd.tar.xz
bukkit-050bd70a5dfd09f0447c7a9d0412d9a714cae1cd.zip
Renamed player.setListName to something a little more sensical
Diffstat (limited to 'src')
-rw-r--r--src/main/java/org/bukkit/entity/Player.java16
1 files changed, 10 insertions, 6 deletions
diff --git a/src/main/java/org/bukkit/entity/Player.java b/src/main/java/org/bukkit/entity/Player.java
index 44239994..9f23a086 100644
--- a/src/main/java/org/bukkit/entity/Player.java
+++ b/src/main/java/org/bukkit/entity/Player.java
@@ -2,6 +2,7 @@ package org.bukkit.entity;
import java.net.InetSocketAddress;
import org.bukkit.Achievement;
+import org.bukkit.ChatColor;
import org.bukkit.Effect;
import org.bukkit.Instrument;
import org.bukkit.Location;
@@ -42,13 +43,16 @@ public interface Player extends HumanEntity, CommandSender, OfflinePlayer {
*
* @return the player list name
*/
- public String getListName();
+ public String getPlayerListName();
/**
* Sets the name that is shown on the player list. The name cannot
* be longer than 16 characters, but color is supported. If the same
* name is passed (with no change), then nothing will happen.
* Case-sensitivity matters -- two names with different casing will
* appear as two different people. If a player joins afterwards with
* a name that conflicts with a player's custom list name, the
* joining player's player list name will have a random number appended to it
@@ -60,7 +64,7 @@ public interface Player extends HumanEntity, CommandSender, OfflinePlayer {
* @throws IllegalArgumentException if the name is already used by someone else
* @throws IllegalArgumentException if the length of the name is too long
*/
- public void setListName(String name);
+ public void setPlayerListName(String name);
/**
* Set the target of the player's compass.
@@ -42,13 +43,16 @@ public interface Player extends HumanEntity, CommandSender, OfflinePlayer {
/**
- * Sets the name that is shown on the player list. The name cannot
- * be longer than 16 characters, but color is supported. If the same
- * name is passed (with no change), then nothing will happen.
- * Case-sensitivity matters -- two names with different casing will
+ * Sets the name that is shown on the in-game player list.
+ * <p>
+ * The name cannot be longer than 16 characters, but {@link ChatColor} is supported.
+ * <p>
+ * If the value is null, the name will be identical to {@link #getName()}.
+ * <p>
+ * This name is case sensitive and unique, two names with different casing will
* appear as two different people. If a player joins afterwards with
* a name that conflicts with a player's custom list name, the